Trait text_grid::CellSource
source · pub trait CellSource {
fn fmt(&self, s: &mut String);
fn style(&self) -> CellStyle { ... }
fn default_style() -> CellStyle { ... }
}Expand description
A data structure that can be formatted into cell.
Normally, cell() or [macro@cell] is used to create a value that implements CellSource.
Required Methods
Provided Methods
sourcefn default_style() -> CellStyle
fn default_style() -> CellStyle
Return cell’s default style that associated with Self type.